# Installation
> `npm install --save @types/react-native-autocomplete-input`

# Summary
This package contains type definitions for react-native-autocomplete-input (https://github.com/mrlaessig/react-native-autocomplete-input#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-native-autocomplete-input.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-native-autocomplete-input/index.d.ts)
````ts
import { FC, ReactNode } from "react";
import { FlatListProps, GestureResponderHandlers, StyleProp, TextInputProps, ViewStyle } from "react-native";

export interface AutocompleteProps<T> extends TextInputProps {
    /**
     * style
     * These styles will be applied to the container which surrounds the autocomplete component.
     */
    containerStyle?: StyleProp<ViewStyle> | undefined;

    /**
     * bool
     * Set to true to hide the suggestion list.
     */
    hideResults?: boolean | undefined;

    /**
     * array
     * An array with suggestion items to be rendered in renderItem({ item, index }). Any array with length > 0 will open the suggestion list and any array with length < 1 will hide the list.
     */
    data: T[];

    /**
     * object
     * Props to pass on to the underlying FlatList.
     */
    flatListProps?: Partial<FlatListProps<T>> | undefined;

    /**
     * style
     * These styles will be applied to the container which surrounds the textInput component.
     */
    inputContainerStyle?: StyleProp<ViewStyle> | undefined;

    /**
     * style
     * These styles will be applied to the container which surrounds the result list.
     */
    listContainerStyle?: StyleProp<ViewStyle> | undefined;

    /**
     * style
     * These style will be applied to the result list.
     */
    listStyle?: StyleProp<ViewStyle> | undefined;

    /**
     * function
     * onShowResults will be called when the autocomplete suggestions appear or disappear.
     */
    onShowResults?(showResults: boolean): void;

    /**
     * function
     * onStartShouldSetResponderCapture will be passed to the result list view container (onStartShouldSetResponderCapture).
     */
    onStartShouldSetResponderCapture?: GestureResponderHandlers["onStartShouldSetResponderCapture"] | undefined;

    /**
     * function
     * render custom TextInput. All props passed to this function.
     */
    renderTextInput?(props: AutocompleteProps<T>): ReactNode;

    /**
     * function
     * render custom result list. Can be used to replace FlatList. All props passed to this function.
     */
    renderResultList?(props: AutocompleteProps<T>): ReactNode;
}
export const AutocompleteInput: FC<AutocompleteProps<any>>;

export default AutocompleteInput;

````

### Additional Details
 * Last updated: Tue, 07 Nov 2023 20:08:00 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react), [@types/react-native](https://npmjs.com/package/@types/react-native)

# Credits
These definitions were written by [Ifiok Jr.](https://github.com/ifiokjr), [Kanitkorn Sujautra](https://github.com/lukyth), [joleb](https://github.com/joleb), and [AJ](https://github.com/ajenkins).
